# SSZZ
Simple SZZ

### Install

```
pip install sszz
```

### Usage:

```
python -m sszz.sszz --repo "/local/path/to/repo" --commit 270239a53ffdc00ece5a9a92f19880a1f50020d2
```

### Contact

Feel free to send me an email if you need help using the tool.

